# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing_extensions import Self

from slurmrestpy.models.v0040_cron_entry import V0040CronEntry
from slurmrestpy.models.v0040_job_desc_msg_rlimits import V0040JobDescMsgRlimits
from slurmrestpy.models.v0040_uint16_no_val import V0040Uint16NoVal
from slurmrestpy.models.v0040_uint32_no_val import V0040Uint32NoVal
from slurmrestpy.models.v0040_uint64_no_val import V0040Uint64NoVal


class V0040JobDescMsg(BaseModel):
    """
    V0040JobDescMsg
    """  # noqa: E501

    account: Optional[StrictStr] = Field(
        default=None, description="Account associated with the job"
    )
    account_gather_frequency: Optional[StrictStr] = Field(
        default=None,
        description="Job accounting and profiling sampling intervals in seconds",
    )
    admin_comment: Optional[StrictStr] = Field(
        default=None, description="Arbitrary comment made by administrator"
    )
    allocation_node_list: Optional[StrictStr] = Field(
        default=None, description="Local node making the resource allocation"
    )
    allocation_node_port: Optional[StrictInt] = Field(
        default=None, description="Port to send allocation confirmation to"
    )
    argv: Optional[List[StrictStr]] = None
    array: Optional[StrictStr] = Field(
        default=None, description="Job array index value specification"
    )
    batch_features: Optional[StrictStr] = Field(
        default=None, description="Features required for batch script's node"
    )
    begin_time: Optional[V0040Uint64NoVal] = None
    flags: Optional[List[StrictStr]] = None
    burst_buffer: Optional[StrictStr] = Field(
        default=None, description="Burst buffer specifications"
    )
    clusters: Optional[StrictStr] = Field(
        default=None, description="Clusters that a federated job can run on"
    )
    cluster_constraint: Optional[StrictStr] = Field(
        default=None,
        description="Required features that a federated cluster must have to have a sibling job submitted to it",
    )
    comment: Optional[StrictStr] = Field(
        default=None, description="Arbitrary comment made by user"
    )
    contiguous: Optional[StrictBool] = Field(
        default=None, description="True if job requires contiguous nodes"
    )
    container: Optional[StrictStr] = Field(
        default=None, description="Absolute path to OCI container bundle"
    )
    container_id: Optional[StrictStr] = Field(
        default=None, description="OCI container ID"
    )
    cores_per_socket: Optional[StrictInt] = Field(
        default=None, description="Cores per socket required"
    )
    core_specification: Optional[StrictInt] = Field(
        default=None, description="Specialized core count"
    )
    thread_specification: Optional[StrictInt] = Field(
        default=None, description="Specialized thread count"
    )
    cpu_binding: Optional[StrictStr] = Field(
        default=None, description="Method for binding tasks to allocated CPUs"
    )
    cpu_binding_flags: Optional[List[StrictStr]] = None
    cpu_frequency: Optional[StrictStr] = Field(
        default=None, description="Requested CPU frequency range <p1>[-p2][:p3]"
    )
    cpus_per_tres: Optional[StrictStr] = Field(
        default=None,
        description="Semicolon delimited list of TRES=# values values indicating how many CPUs should be allocated for each specified TRES (currently only used for gres/gpu)",
    )
    crontab: Optional[V0040CronEntry] = None
    deadline: Optional[StrictInt] = Field(
        default=None, description="Latest time that the job may start (UNIX timestamp)"
    )
    delay_boot: Optional[StrictInt] = Field(
        default=None,
        description="Number of seconds after job eligible start that nodes will be rebooted to satisfy feature specification",
    )
    dependency: Optional[StrictStr] = Field(
        default=None,
        description="Other jobs that must meet certain criteria before this job can start",
    )
    end_time: Optional[StrictInt] = Field(
        default=None, description="Expected end time (UNIX timestamp)"
    )
    environment: Optional[List[StrictStr]] = None
    rlimits: Optional[V0040JobDescMsgRlimits] = None
    excluded_nodes: Optional[List[StrictStr]] = None
    extra: Optional[StrictStr] = Field(
        default=None,
        description="Arbitrary string used for node filtering if extra constraints are enabled",
    )
    constraints: Optional[StrictStr] = Field(
        default=None, description="Comma separated list of features that are required"
    )
    group_id: Optional[StrictStr] = Field(
        default=None, description="Group ID of the user that owns the job"
    )
    hetjob_group: Optional[StrictInt] = Field(
        default=None,
        description="Unique sequence number applied to this component of the heterogeneous job",
    )
    immediate: Optional[StrictBool] = Field(
        default=None,
        description="If true, exit if resources are not available within the time period specified",
    )
    job_id: Optional[StrictInt] = Field(default=None, description="Job ID")
    kill_on_node_fail: Optional[StrictBool] = Field(
        default=None, description="If true, kill job on node failure"
    )
    licenses: Optional[StrictStr] = Field(
        default=None, description="License(s) required by the job"
    )
    mail_type: Optional[List[StrictStr]] = None
    mail_user: Optional[StrictStr] = Field(
        default=None, description="User to receive email notifications"
    )
    mcs_label: Optional[StrictStr] = Field(
        default=None, description="Multi-Category Security label on the job"
    )
    memory_binding: Optional[StrictStr] = Field(
        default=None, description="Binding map for map/mask_cpu"
    )
    memory_binding_type: Optional[List[StrictStr]] = None
    memory_per_tres: Optional[StrictStr] = Field(
        default=None,
        description="Semicolon delimited list of TRES=# values indicating how much memory in megabytes should be allocated for each specified TRES (currently only used for gres/gpu)",
    )
    name: Optional[StrictStr] = Field(default=None, description="Job name")
    network: Optional[StrictStr] = Field(
        default=None, description="Network specs for job step"
    )
    nice: Optional[StrictInt] = Field(
        default=None, description="Requested job priority change"
    )
    tasks: Optional[StrictInt] = Field(default=None, description="Number of tasks")
    open_mode: Optional[List[StrictStr]] = None
    reserve_ports: Optional[StrictInt] = Field(
        default=None, description="Port to send various notification msg to"
    )
    overcommit: Optional[StrictBool] = Field(
        default=None, description="Overcommit resources"
    )
    partition: Optional[StrictStr] = Field(
        default=None, description="Partition assigned to the job"
    )
    distribution_plane_size: Optional[StrictInt] = Field(
        default=None,
        description="Plane size specification when distribution specifies plane",
    )
    power_flags: Optional[List[Any]] = Field(default=None, description="removed field")
    prefer: Optional[StrictStr] = Field(
        default=None,
        description="Comma separated list of features that are preferred but not required",
    )
    hold: Optional[StrictBool] = Field(default=None, description="Job held")
    priority: Optional[V0040Uint32NoVal] = None
    profile: Optional[List[StrictStr]] = None
    qos: Optional[StrictStr] = Field(
        default=None, description="Quality of Service assigned to the job"
    )
    reboot: Optional[StrictBool] = Field(
        default=None, description="Node reboot requested before start"
    )
    required_nodes: Optional[List[StrictStr]] = None
    requeue: Optional[StrictBool] = Field(
        default=None, description="Determines whether the job may be requeued"
    )
    reservation: Optional[StrictStr] = Field(
        default=None, description="Name of reservation to use"
    )
    script: Optional[StrictStr] = Field(
        default=None,
        description="Job batch script; only the first component in a HetJob is populated or honored",
    )
    shared: Optional[List[StrictStr]] = None
    exclusive: Optional[List[StrictStr]] = None
    oversubscribe: Optional[StrictBool] = None
    site_factor: Optional[StrictInt] = Field(
        default=None, description="Site-specific priority factor"
    )
    spank_environment: Optional[List[StrictStr]] = None
    distribution: Optional[StrictStr] = Field(default=None, description="Layout")
    time_limit: Optional[V0040Uint32NoVal] = None
    time_minimum: Optional[V0040Uint32NoVal] = None
    tres_bind: Optional[StrictStr] = Field(
        default=None, description="Task to TRES binding directives"
    )
    tres_freq: Optional[StrictStr] = Field(
        default=None, description="TRES frequency directives"
    )
    tres_per_job: Optional[StrictStr] = Field(
        default=None,
        description="Comma separated list of TRES=# values to be allocated for every job",
    )
    tres_per_node: Optional[StrictStr] = Field(
        default=None,
        description="Comma separated list of TRES=# values to be allocated for every node",
    )
    tres_per_socket: Optional[StrictStr] = Field(
        default=None,
        description="Comma separated list of TRES=# values to be allocated for every socket",
    )
    tres_per_task: Optional[StrictStr] = Field(
        default=None,
        description="Comma separated list of TRES=# values to be allocated for every task",
    )
    user_id: Optional[StrictStr] = Field(
        default=None, description="User ID that owns the job"
    )
    wait_all_nodes: Optional[StrictBool] = Field(
        default=None,
        description="If true, wait to start until after all nodes have booted",
    )
    kill_warning_flags: Optional[List[StrictStr]] = None
    kill_warning_signal: Optional[StrictStr] = Field(
        default=None,
        description='Signal to send when approaching end time (e.g. "10" or "USR1")',
    )
    kill_warning_delay: Optional[V0040Uint16NoVal] = None
    current_working_directory: Optional[StrictStr] = Field(
        default=None, description="Working directory to use for the job"
    )
    cpus_per_task: Optional[StrictInt] = Field(
        default=None, description="Number of CPUs required by each task"
    )
    minimum_cpus: Optional[StrictInt] = Field(
        default=None, description="Minimum number of CPUs required"
    )
    maximum_cpus: Optional[StrictInt] = Field(
        default=None, description="Maximum number of CPUs required"
    )
    nodes: Optional[StrictStr] = Field(
        default=None, description="Node count range specification (e.g. 1-15:4)"
    )
    minimum_nodes: Optional[StrictInt] = Field(
        default=None, description="Minimum node count"
    )
    maximum_nodes: Optional[StrictInt] = Field(
        default=None, description="Maximum node count"
    )
    minimum_boards_per_node: Optional[StrictInt] = Field(
        default=None, description="Boards per node required"
    )
    minimum_sockets_per_board: Optional[StrictInt] = Field(
        default=None, description="Sockets per board required"
    )
    sockets_per_node: Optional[StrictInt] = Field(
        default=None, description="Sockets per node required"
    )
    threads_per_core: Optional[StrictInt] = Field(
        default=None, description="Threads per core required"
    )
    tasks_per_node: Optional[StrictInt] = Field(
        default=None, description="Number of tasks to invoke on each node"
    )
    tasks_per_socket: Optional[StrictInt] = Field(
        default=None, description="Number of tasks to invoke on each socket"
    )
    tasks_per_core: Optional[StrictInt] = Field(
        default=None, description="Number of tasks to invoke on each core"
    )
    tasks_per_board: Optional[StrictInt] = Field(
        default=None, description="Number of tasks to invoke on each board"
    )
    ntasks_per_tres: Optional[StrictInt] = Field(
        default=None, description="Number of tasks that can access each GPU"
    )
    minimum_cpus_per_node: Optional[StrictInt] = Field(
        default=None, description="Minimum number of CPUs per node"
    )
    memory_per_cpu: Optional[V0040Uint64NoVal] = None
    memory_per_node: Optional[V0040Uint64NoVal] = None
    temporary_disk_per_node: Optional[StrictInt] = Field(
        default=None, description="Minimum tmp disk space required per node"
    )
    selinux_context: Optional[StrictStr] = Field(
        default=None, description="SELinux context"
    )
    required_switches: Optional[V0040Uint32NoVal] = None
    standard_error: Optional[StrictStr] = Field(
        default=None, description="Path to stderr file"
    )
    standard_input: Optional[StrictStr] = Field(
        default=None, description="Path to stdin file"
    )
    standard_output: Optional[StrictStr] = Field(
        default=None, description="Path to stdout file"
    )
    wait_for_switch: Optional[StrictInt] = Field(
        default=None, description="Maximum time to wait for switches in seconds"
    )
    wckey: Optional[StrictStr] = Field(
        default=None, description="Workload characterization key"
    )
    x11: Optional[List[StrictStr]] = None
    x11_magic_cookie: Optional[StrictStr] = Field(
        default=None, description="Magic cookie for X11 forwarding"
    )
    x11_target_host: Optional[StrictStr] = Field(
        default=None, description="Hostname or UNIX socket if x11_target_port=0"
    )
    x11_target_port: Optional[StrictInt] = Field(default=None, description="TCP port")
    __properties: ClassVar[List[str]] = [
        "account",
        "account_gather_frequency",
        "admin_comment",
        "allocation_node_list",
        "allocation_node_port",
        "argv",
        "array",
        "batch_features",
        "begin_time",
        "flags",
        "burst_buffer",
        "clusters",
        "cluster_constraint",
        "comment",
        "contiguous",
        "container",
        "container_id",
        "cores_per_socket",
        "core_specification",
        "thread_specification",
        "cpu_binding",
        "cpu_binding_flags",
        "cpu_frequency",
        "cpus_per_tres",
        "crontab",
        "deadline",
        "delay_boot",
        "dependency",
        "end_time",
        "environment",
        "rlimits",
        "excluded_nodes",
        "extra",
        "constraints",
        "group_id",
        "hetjob_group",
        "immediate",
        "job_id",
        "kill_on_node_fail",
        "licenses",
        "mail_type",
        "mail_user",
        "mcs_label",
        "memory_binding",
        "memory_binding_type",
        "memory_per_tres",
        "name",
        "network",
        "nice",
        "tasks",
        "open_mode",
        "reserve_ports",
        "overcommit",
        "partition",
        "distribution_plane_size",
        "power_flags",
        "prefer",
        "hold",
        "priority",
        "profile",
        "qos",
        "reboot",
        "required_nodes",
        "requeue",
        "reservation",
        "script",
        "shared",
        "exclusive",
        "oversubscribe",
        "site_factor",
        "spank_environment",
        "distribution",
        "time_limit",
        "time_minimum",
        "tres_bind",
        "tres_freq",
        "tres_per_job",
        "tres_per_node",
        "tres_per_socket",
        "tres_per_task",
        "user_id",
        "wait_all_nodes",
        "kill_warning_flags",
        "kill_warning_signal",
        "kill_warning_delay",
        "current_working_directory",
        "cpus_per_task",
        "minimum_cpus",
        "maximum_cpus",
        "nodes",
        "minimum_nodes",
        "maximum_nodes",
        "minimum_boards_per_node",
        "minimum_sockets_per_board",
        "sockets_per_node",
        "threads_per_core",
        "tasks_per_node",
        "tasks_per_socket",
        "tasks_per_core",
        "tasks_per_board",
        "ntasks_per_tres",
        "minimum_cpus_per_node",
        "memory_per_cpu",
        "memory_per_node",
        "temporary_disk_per_node",
        "selinux_context",
        "required_switches",
        "standard_error",
        "standard_input",
        "standard_output",
        "wait_for_switch",
        "wckey",
        "x11",
        "x11_magic_cookie",
        "x11_target_host",
        "x11_target_port",
    ]

    @field_validator("flags")
    def flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "KILL_INVALID_DEPENDENCY",
                    "NO_KILL_INVALID_DEPENDENCY",
                    "HAS_STATE_DIRECTORY",
                    "TESTING_BACKFILL",
                    "GRES_BINDING_ENFORCED",
                    "TEST_NOW_ONLY",
                    "SEND_JOB_ENVIRONMENT",
                    "SPREAD_JOB",
                    "PREFER_MINIMUM_NODE_COUNT",
                    "JOB_KILL_HURRY",
                    "SKIP_TRES_STRING_ACCOUNTING",
                    "SIBLING_CLUSTER_UPDATE_ONLY",
                    "HETEROGENEOUS_JOB",
                    "EXACT_TASK_COUNT_REQUESTED",
                    "EXACT_CPU_COUNT_REQUESTED",
                    "TESTING_WHOLE_NODE_BACKFILL",
                    "TOP_PRIORITY_JOB",
                    "ACCRUE_COUNT_CLEARED",
                    "GRES_BINDING_DISABLED",
                    "JOB_WAS_RUNNING",
                    "JOB_ACCRUE_TIME_RESET",
                    "CRON_JOB",
                    "EXACT_MEMORY_REQUESTED",
                    "USING_DEFAULT_ACCOUNT",
                    "USING_DEFAULT_PARTITION",
                    "USING_DEFAULT_QOS",
                    "USING_DEFAULT_WCKEY",
                    "DEPENDENT",
                    "MAGNETIC",
                    "PARTITION_ASSIGNED",
                    "BACKFILL_ATTEMPTED",
                    "SCHEDULING_ATTEMPTED",
                    "SAVE_BATCH_SCRIPT",
                    "GRES_ONE_TASK_PER_SHARING",
                    "GRES_MULTIPLE_TASKS_PER_SHARING",
                    "GRES_ALLOW_TASK_SHARING",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('KILL_INVALID_DEPENDENCY', 'NO_KILL_INVALID_DEPENDENCY', 'HAS_STATE_DIRECTORY', 'TESTING_BACKFILL', 'GRES_BINDING_ENFORCED', 'TEST_NOW_ONLY', 'SEND_JOB_ENVIRONMENT', 'SPREAD_JOB', 'PREFER_MINIMUM_NODE_COUNT', 'JOB_KILL_HURRY', 'SKIP_TRES_STRING_ACCOUNTING', 'SIBLING_CLUSTER_UPDATE_ONLY', 'HETEROGENEOUS_JOB', 'EXACT_TASK_COUNT_REQUESTED', 'EXACT_CPU_COUNT_REQUESTED', 'TESTING_WHOLE_NODE_BACKFILL', 'TOP_PRIORITY_JOB', 'ACCRUE_COUNT_CLEARED', 'GRES_BINDING_DISABLED', 'JOB_WAS_RUNNING', 'JOB_ACCRUE_TIME_RESET', 'CRON_JOB', 'EXACT_MEMORY_REQUESTED', 'USING_DEFAULT_ACCOUNT', 'USING_DEFAULT_PARTITION', 'USING_DEFAULT_QOS', 'USING_DEFAULT_WCKEY', 'DEPENDENT', 'MAGNETIC', 'PARTITION_ASSIGNED', 'BACKFILL_ATTEMPTED', 'SCHEDULING_ATTEMPTED', 'SAVE_BATCH_SCRIPT', 'GRES_ONE_TASK_PER_SHARING', 'GRES_MULTIPLE_TASKS_PER_SHARING', 'GRES_ALLOW_TASK_SHARING')"
                )
        return value

    @field_validator("cpu_binding_flags")
    def cpu_binding_flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "CPU_BIND_TO_THREADS",
                    "CPU_BIND_TO_CORES",
                    "CPU_BIND_TO_SOCKETS",
                    "CPU_BIND_TO_LDOMS",
                    "CPU_BIND_NONE",
                    "CPU_BIND_RANK",
                    "CPU_BIND_MAP",
                    "CPU_BIND_MASK",
                    "CPU_BIND_LDRANK",
                    "CPU_BIND_LDMAP",
                    "CPU_BIND_LDMASK",
                    "VERBOSE",
                    "CPU_BIND_ONE_THREAD_PER_CORE",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('CPU_BIND_TO_THREADS', 'CPU_BIND_TO_CORES', 'CPU_BIND_TO_SOCKETS', 'CPU_BIND_TO_LDOMS', 'CPU_BIND_NONE', 'CPU_BIND_RANK', 'CPU_BIND_MAP', 'CPU_BIND_MASK', 'CPU_BIND_LDRANK', 'CPU_BIND_LDMAP', 'CPU_BIND_LDMASK', 'VERBOSE', 'CPU_BIND_ONE_THREAD_PER_CORE')"
                )
        return value

    @field_validator("mail_type")
    def mail_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "BEGIN",
                    "END",
                    "FAIL",
                    "REQUEUE",
                    "TIME=100%",
                    "TIME=90%",
                    "TIME=80%",
                    "TIME=50%",
                    "STAGE_OUT",
                    "ARRAY_TASKS",
                    "INVALID_DEPENDENCY",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('BEGIN', 'END', 'FAIL', 'REQUEUE', 'TIME=100%', 'TIME=90%', 'TIME=80%', 'TIME=50%', 'STAGE_OUT', 'ARRAY_TASKS', 'INVALID_DEPENDENCY')"
                )
        return value

    @field_validator("memory_binding_type")
    def memory_binding_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                ["NONE", "RANK", "MAP", "MASK", "LOCAL", "VERBOSE", "SORT", "PREFER"]
            ):
                raise ValueError(
                    "each list item must be one of ('NONE', 'RANK', 'MAP', 'MASK', 'LOCAL', 'VERBOSE', 'SORT', 'PREFER')"
                )
        return value

    @field_validator("open_mode")
    def open_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["APPEND", "TRUNCATE"]):
                raise ValueError("each list item must be one of ('APPEND', 'TRUNCATE')")
        return value

    @field_validator("profile")
    def profile_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["NOT_SET", "NONE", "ENERGY", "LUSTRE", "NETWORK", "TASK"]):
                raise ValueError(
                    "each list item must be one of ('NOT_SET', 'NONE', 'ENERGY', 'LUSTRE', 'NETWORK', 'TASK')"
                )
        return value

    @field_validator("shared")
    def shared_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["none", "oversubscribe", "user", "mcs"]):
                raise ValueError(
                    "each list item must be one of ('none', 'oversubscribe', 'user', 'mcs')"
                )
        return value

    @field_validator("exclusive")
    def exclusive_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["true", "false", "user", "mcs"]):
                raise ValueError(
                    "each list item must be one of ('true', 'false', 'user', 'mcs')"
                )
        return value

    @field_validator("kill_warning_flags")
    def kill_warning_flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "BATCH_JOB",
                    "ARRAY_TASK",
                    "FULL_STEPS_ONLY",
                    "FULL_JOB",
                    "FEDERATION_REQUEUE",
                    "HURRY",
                    "OUT_OF_MEMORY",
                    "NO_SIBLING_JOBS",
                    "RESERVATION_JOB",
                    "NO_CRON_JOBS",
                    "VERBOSE",
                    "CRON_JOBS",
                    "WARNING_SENT",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('BATCH_JOB', 'ARRAY_TASK', 'FULL_STEPS_ONLY', 'FULL_JOB', 'FEDERATION_REQUEUE', 'HURRY', 'OUT_OF_MEMORY', 'NO_SIBLING_JOBS', 'RESERVATION_JOB', 'NO_CRON_JOBS', 'VERBOSE', 'CRON_JOBS', 'WARNING_SENT')"
                )
        return value

    @field_validator("x11")
    def x11_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                ["FORWARD_ALL_NODES", "BATCH_NODE", "FIRST_NODE", "LAST_NODE"]
            ):
                raise ValueError(
                    "each list item must be one of ('FORWARD_ALL_NODES', 'BATCH_NODE', 'FIRST_NODE', 'LAST_NODE')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0040JobDescMsg from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of begin_time
        if self.begin_time:
            _dict["begin_time"] = self.begin_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of crontab
        if self.crontab:
            _dict["crontab"] = self.crontab.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rlimits
        if self.rlimits:
            _dict["rlimits"] = self.rlimits.to_dict()
        # override the default output from pydantic by calling `to_dict()` of priority
        if self.priority:
            _dict["priority"] = self.priority.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time_limit
        if self.time_limit:
            _dict["time_limit"] = self.time_limit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time_minimum
        if self.time_minimum:
            _dict["time_minimum"] = self.time_minimum.to_dict()
        # override the default output from pydantic by calling `to_dict()` of kill_warning_delay
        if self.kill_warning_delay:
            _dict["kill_warning_delay"] = self.kill_warning_delay.to_dict()
        # override the default output from pydantic by calling `to_dict()` of memory_per_cpu
        if self.memory_per_cpu:
            _dict["memory_per_cpu"] = self.memory_per_cpu.to_dict()
        # override the default output from pydantic by calling `to_dict()` of memory_per_node
        if self.memory_per_node:
            _dict["memory_per_node"] = self.memory_per_node.to_dict()
        # override the default output from pydantic by calling `to_dict()` of required_switches
        if self.required_switches:
            _dict["required_switches"] = self.required_switches.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0040JobDescMsg from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "account": obj.get("account"),
                "account_gather_frequency": obj.get("account_gather_frequency"),
                "admin_comment": obj.get("admin_comment"),
                "allocation_node_list": obj.get("allocation_node_list"),
                "allocation_node_port": obj.get("allocation_node_port"),
                "argv": obj.get("argv"),
                "array": obj.get("array"),
                "batch_features": obj.get("batch_features"),
                "begin_time": V0040Uint64NoVal.from_dict(obj["begin_time"])
                if obj.get("begin_time") is not None
                else None,
                "flags": obj.get("flags"),
                "burst_buffer": obj.get("burst_buffer"),
                "clusters": obj.get("clusters"),
                "cluster_constraint": obj.get("cluster_constraint"),
                "comment": obj.get("comment"),
                "contiguous": obj.get("contiguous"),
                "container": obj.get("container"),
                "container_id": obj.get("container_id"),
                "cores_per_socket": obj.get("cores_per_socket"),
                "core_specification": obj.get("core_specification"),
                "thread_specification": obj.get("thread_specification"),
                "cpu_binding": obj.get("cpu_binding"),
                "cpu_binding_flags": obj.get("cpu_binding_flags"),
                "cpu_frequency": obj.get("cpu_frequency"),
                "cpus_per_tres": obj.get("cpus_per_tres"),
                "crontab": V0040CronEntry.from_dict(obj["crontab"])
                if obj.get("crontab") is not None
                else None,
                "deadline": obj.get("deadline"),
                "delay_boot": obj.get("delay_boot"),
                "dependency": obj.get("dependency"),
                "end_time": obj.get("end_time"),
                "environment": obj.get("environment"),
                "rlimits": V0040JobDescMsgRlimits.from_dict(obj["rlimits"])
                if obj.get("rlimits") is not None
                else None,
                "excluded_nodes": obj.get("excluded_nodes"),
                "extra": obj.get("extra"),
                "constraints": obj.get("constraints"),
                "group_id": obj.get("group_id"),
                "hetjob_group": obj.get("hetjob_group"),
                "immediate": obj.get("immediate"),
                "job_id": obj.get("job_id"),
                "kill_on_node_fail": obj.get("kill_on_node_fail"),
                "licenses": obj.get("licenses"),
                "mail_type": obj.get("mail_type"),
                "mail_user": obj.get("mail_user"),
                "mcs_label": obj.get("mcs_label"),
                "memory_binding": obj.get("memory_binding"),
                "memory_binding_type": obj.get("memory_binding_type"),
                "memory_per_tres": obj.get("memory_per_tres"),
                "name": obj.get("name"),
                "network": obj.get("network"),
                "nice": obj.get("nice"),
                "tasks": obj.get("tasks"),
                "open_mode": obj.get("open_mode"),
                "reserve_ports": obj.get("reserve_ports"),
                "overcommit": obj.get("overcommit"),
                "partition": obj.get("partition"),
                "distribution_plane_size": obj.get("distribution_plane_size"),
                "power_flags": obj.get("power_flags"),
                "prefer": obj.get("prefer"),
                "hold": obj.get("hold"),
                "priority": V0040Uint32NoVal.from_dict(obj["priority"])
                if obj.get("priority") is not None
                else None,
                "profile": obj.get("profile"),
                "qos": obj.get("qos"),
                "reboot": obj.get("reboot"),
                "required_nodes": obj.get("required_nodes"),
                "requeue": obj.get("requeue"),
                "reservation": obj.get("reservation"),
                "script": obj.get("script"),
                "shared": obj.get("shared"),
                "exclusive": obj.get("exclusive"),
                "oversubscribe": obj.get("oversubscribe"),
                "site_factor": obj.get("site_factor"),
                "spank_environment": obj.get("spank_environment"),
                "distribution": obj.get("distribution"),
                "time_limit": V0040Uint32NoVal.from_dict(obj["time_limit"])
                if obj.get("time_limit") is not None
                else None,
                "time_minimum": V0040Uint32NoVal.from_dict(obj["time_minimum"])
                if obj.get("time_minimum") is not None
                else None,
                "tres_bind": obj.get("tres_bind"),
                "tres_freq": obj.get("tres_freq"),
                "tres_per_job": obj.get("tres_per_job"),
                "tres_per_node": obj.get("tres_per_node"),
                "tres_per_socket": obj.get("tres_per_socket"),
                "tres_per_task": obj.get("tres_per_task"),
                "user_id": obj.get("user_id"),
                "wait_all_nodes": obj.get("wait_all_nodes"),
                "kill_warning_flags": obj.get("kill_warning_flags"),
                "kill_warning_signal": obj.get("kill_warning_signal"),
                "kill_warning_delay": V0040Uint16NoVal.from_dict(
                    obj["kill_warning_delay"]
                )
                if obj.get("kill_warning_delay") is not None
                else None,
                "current_working_directory": obj.get("current_working_directory"),
                "cpus_per_task": obj.get("cpus_per_task"),
                "minimum_cpus": obj.get("minimum_cpus"),
                "maximum_cpus": obj.get("maximum_cpus"),
                "nodes": obj.get("nodes"),
                "minimum_nodes": obj.get("minimum_nodes"),
                "maximum_nodes": obj.get("maximum_nodes"),
                "minimum_boards_per_node": obj.get("minimum_boards_per_node"),
                "minimum_sockets_per_board": obj.get("minimum_sockets_per_board"),
                "sockets_per_node": obj.get("sockets_per_node"),
                "threads_per_core": obj.get("threads_per_core"),
                "tasks_per_node": obj.get("tasks_per_node"),
                "tasks_per_socket": obj.get("tasks_per_socket"),
                "tasks_per_core": obj.get("tasks_per_core"),
                "tasks_per_board": obj.get("tasks_per_board"),
                "ntasks_per_tres": obj.get("ntasks_per_tres"),
                "minimum_cpus_per_node": obj.get("minimum_cpus_per_node"),
                "memory_per_cpu": V0040Uint64NoVal.from_dict(obj["memory_per_cpu"])
                if obj.get("memory_per_cpu") is not None
                else None,
                "memory_per_node": V0040Uint64NoVal.from_dict(obj["memory_per_node"])
                if obj.get("memory_per_node") is not None
                else None,
                "temporary_disk_per_node": obj.get("temporary_disk_per_node"),
                "selinux_context": obj.get("selinux_context"),
                "required_switches": V0040Uint32NoVal.from_dict(
                    obj["required_switches"]
                )
                if obj.get("required_switches") is not None
                else None,
                "standard_error": obj.get("standard_error"),
                "standard_input": obj.get("standard_input"),
                "standard_output": obj.get("standard_output"),
                "wait_for_switch": obj.get("wait_for_switch"),
                "wckey": obj.get("wckey"),
                "x11": obj.get("x11"),
                "x11_magic_cookie": obj.get("x11_magic_cookie"),
                "x11_target_host": obj.get("x11_target_host"),
                "x11_target_port": obj.get("x11_target_port"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp import (
    V0041OpenapiSlurmdbdJobsResp,
)


class TestV0041OpenapiSlurmdbdJobsResp(unittest.TestCase):
    """V0041OpenapiSlurmdbdJobsResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiSlurmdbdJobsResp:
        """Test V0041OpenapiSlurmdbdJobsResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdJobsResp`
        """
        model = V0041OpenapiSlurmdbdJobsResp()
        if include_optional:
            return V0041OpenapiSlurmdbdJobsResp(
                jobs = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner(
                        account = '',
                        comment = slurmrestpy.models.v0_0_42_job_comment.v0_0_42_job_comment(
                            administrator = '',
                            job = '',
                            system = '', ),
                        allocation_nodes = 56,
                        array = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array(
                            job_id = 56,
                            limits = slurmrestpy.models.v0_0_42_job_array_limits.v0_0_42_job_array_limits(
                                max = slurmrestpy.models.v0_0_42_job_array_limits_max.v0_0_42_job_array_limits_max(
                                    running = slurmrestpy.models.v0_0_42_job_array_limits_max_running.v0_0_42_job_array_limits_max_running(
                                        tasks = 56, ), ), ),
                            task_id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            task = '', ),
                        association = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_association.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_association(
                            account = '',
                            cluster = '',
                            partition = '',
                            user = '',
                            id = 56, ),
                        block = '',
                        cluster = '',
                        constraints = '',
                        container = '',
                        derived_exit_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code(
                            status = [
                                'INVALID'
                                ],
                            return_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            signal = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal(
                                id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id(
                                    set = True,
                                    infinite = True,
                                    number = 56, ),
                                name = '', ), ),
                        time = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time(
                            elapsed = 56,
                            eligible = 56,
                            end = 56,
                            planned = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_planned.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_planned(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            start = 56,
                            submission = 56,
                            suspended = 56,
                            system = slurmrestpy.models.v0_0_42_job_time_system.v0_0_42_job_time_system(
                                seconds = 56,
                                microseconds = 56, ),
                            limit = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            total = slurmrestpy.models.v0_0_42_job_time_total.v0_0_42_job_time_total(
                                seconds = 56,
                                microseconds = 56, ),
                            user = slurmrestpy.models.v0_0_42_job_time_user.v0_0_42_job_time_user(
                                seconds = 56,
                                microseconds = 56, ), ),
                        exit_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_exit_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_exit_code(),
                        extra = '',
                        failed_node = '',
                        flags = [
                            'NONE'
                            ],
                        group = '',
                        het = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het(
                            job_id = 56,
                            job_offset = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        job_id = 56,
                        name = '',
                        licenses = '',
                        mcs = slurmrestpy.models.v0_0_42_job_mcs.v0_0_42_job_mcs(
                            label = '', ),
                        nodes = '',
                        partition = '',
                        hold = True,
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        qos = '',
                        required = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required(
                            cpus = 56,
                            memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            memory_per_node = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        kill_request_user = '',
                        reservation = slurmrestpy.models.v0_0_42_job_reservation.v0_0_42_job_reservation(
                            name = '', ),
                        script = '',
                        stdin_expanded = '',
                        stdout_expanded = '',
                        stderr_expanded = '',
                        stdout = '',
                        stderr = '',
                        stdin = '',
                        state = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_state.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_state(
                            current = [
                                'PENDING'
                                ],
                            reason = '', ),
                        steps = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner(
                                nodes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_nodes.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_nodes(
                                    count = 56,
                                    range = '',
                                    list = [
                                        ''
                                        ], ),
                                tasks = slurmrestpy.models.v0_0_42_step_tasks.v0_0_42_step_tasks(
                                    count = 56, ),
                                pid = '',
                                cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_CPU(
                                    requested_frequency = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu_requested_frequency.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_CPU_requested_frequency(
                                        min = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu_requested_frequency_min.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_CPU_requested_frequency_min(
                                            set = True,
                                            infinite = True,
                                            number = 56, ), ),
                                    governor = '', ),
                                kill_request_user = '',
                                statistics = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics(
                                    energy = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy(
                                        consumed = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy_consumed.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy_consumed(
                                            set = True,
                                            infinite = True,
                                            number = 56, ), ), ),
                                step = slurmrestpy.models.v0_0_42_step_step.v0_0_42_step_step(
                                    name = '', ),
                                task = slurmrestpy.models.v0_0_42_step_task.v0_0_42_step_task(
                                    distribution = '', ),
                                tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres(
                                    requested = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested(
                                        average = [
                                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                                type = '',
                                                name = '',
                                                count = 56, )
                                            ], ),
                                    allocated = [
                                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                            type = '',
                                            name = '',
                                            count = 56, )
                                        ], ), )
                            ],
                        submit_line = '',
                        tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_tres.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_tres(),
                        used_gres = '',
                        user = '',
                        wckey = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_wckey.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_wckey(
                            wckey = '',
                            flags = [
                                'ASSIGNED_DEFAULT'
                                ], ),
                        working_directory = '', )
                    ],
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiSlurmdbdJobsResp(
                jobs = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner(
                        account = '',
                        comment = slurmrestpy.models.v0_0_42_job_comment.v0_0_42_job_comment(
                            administrator = '',
                            job = '',
                            system = '', ),
                        allocation_nodes = 56,
                        array = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array(
                            job_id = 56,
                            limits = slurmrestpy.models.v0_0_42_job_array_limits.v0_0_42_job_array_limits(
                                max = slurmrestpy.models.v0_0_42_job_array_limits_max.v0_0_42_job_array_limits_max(
                                    running = slurmrestpy.models.v0_0_42_job_array_limits_max_running.v0_0_42_job_array_limits_max_running(
                                        tasks = 56, ), ), ),
                            task_id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            task = '', ),
                        association = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_association.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_association(
                            account = '',
                            cluster = '',
                            partition = '',
                            user = '',
                            id = 56, ),
                        block = '',
                        cluster = '',
                        constraints = '',
                        container = '',
                        derived_exit_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code(
                            status = [
                                'INVALID'
                                ],
                            return_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            signal = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal(
                                id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id(
                                    set = True,
                                    infinite = True,
                                    number = 56, ),
                                name = '', ), ),
                        time = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time(
                            elapsed = 56,
                            eligible = 56,
                            end = 56,
                            planned = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_planned.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_planned(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            start = 56,
                            submission = 56,
                            suspended = 56,
                            system = slurmrestpy.models.v0_0_42_job_time_system.v0_0_42_job_time_system(
                                seconds = 56,
                                microseconds = 56, ),
                            limit = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            total = slurmrestpy.models.v0_0_42_job_time_total.v0_0_42_job_time_total(
                                seconds = 56,
                                microseconds = 56, ),
                            user = slurmrestpy.models.v0_0_42_job_time_user.v0_0_42_job_time_user(
                                seconds = 56,
                                microseconds = 56, ), ),
                        exit_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_exit_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_exit_code(),
                        extra = '',
                        failed_node = '',
                        flags = [
                            'NONE'
                            ],
                        group = '',
                        het = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het(
                            job_id = 56,
                            job_offset = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        job_id = 56,
                        name = '',
                        licenses = '',
                        mcs = slurmrestpy.models.v0_0_42_job_mcs.v0_0_42_job_mcs(
                            label = '', ),
                        nodes = '',
                        partition = '',
                        hold = True,
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        qos = '',
                        required = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required(
                            cpus = 56,
                            memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            memory_per_node = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        kill_request_user = '',
                        reservation = slurmrestpy.models.v0_0_42_job_reservation.v0_0_42_job_reservation(
                            name = '', ),
                        script = '',
                        stdin_expanded = '',
                        stdout_expanded = '',
                        stderr_expanded = '',
                        stdout = '',
                        stderr = '',
                        stdin = '',
                        state = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_state.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_state(
                            current = [
                                'PENDING'
                                ],
                            reason = '', ),
                        steps = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner(
                                nodes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_nodes.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_nodes(
                                    count = 56,
                                    range = '',
                                    list = [
                                        ''
                                        ], ),
                                tasks = slurmrestpy.models.v0_0_42_step_tasks.v0_0_42_step_tasks(
                                    count = 56, ),
                                pid = '',
                                cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_CPU(
                                    requested_frequency = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu_requested_frequency.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_CPU_requested_frequency(
                                        min = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu_requested_frequency_min.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_CPU_requested_frequency_min(
                                            set = True,
                                            infinite = True,
                                            number = 56, ), ),
                                    governor = '', ),
                                kill_request_user = '',
                                statistics = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics(
                                    energy = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy(
                                        consumed = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy_consumed.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy_consumed(
                                            set = True,
                                            infinite = True,
                                            number = 56, ), ), ),
                                step = slurmrestpy.models.v0_0_42_step_step.v0_0_42_step_step(
                                    name = '', ),
                                task = slurmrestpy.models.v0_0_42_step_task.v0_0_42_step_task(
                                    distribution = '', ),
                                tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres(
                                    requested = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested(
                                        average = [
                                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                                type = '',
                                                name = '',
                                                count = 56, )
                                            ], ),
                                    allocated = [
                                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                            type = '',
                                            name = '',
                                            count = 56, )
                                        ], ), )
                            ],
                        submit_line = '',
                        tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_tres.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_tres(),
                        used_gres = '',
                        user = '',
                        wckey = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_wckey.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_wckey(
                            wckey = '',
                            flags = [
                                'ASSIGNED_DEFAULT'
                                ], ),
                        working_directory = '', )
                    ],
        )
        """

    def testV0041OpenapiSlurmdbdJobsResp(self):
        """Test V0041OpenapiSlurmdbdJobsResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Self

from slurmrestpy.models.v0040_partition_info_defaults import V0040PartitionInfoDefaults
from slurmrestpy.models.v0040_partition_info_maximums import V0040PartitionInfoMaximums
from slurmrestpy.models.v0040_partition_info_partition import (
    V0040PartitionInfoPartition,
)
from slurmrestpy.models.v0040_partition_info_timeouts import V0040PartitionInfoTimeouts
from slurmrestpy.models.v0040_uint32_no_val import V0040Uint32NoVal
from slurmrestpy.models.v0042_partition_info_accounts import V0042PartitionInfoAccounts
from slurmrestpy.models.v0042_partition_info_cpus import V0042PartitionInfoCpus
from slurmrestpy.models.v0042_partition_info_groups import V0042PartitionInfoGroups
from slurmrestpy.models.v0042_partition_info_minimums import V0042PartitionInfoMinimums
from slurmrestpy.models.v0042_partition_info_nodes import V0042PartitionInfoNodes
from slurmrestpy.models.v0042_partition_info_priority import V0042PartitionInfoPriority
from slurmrestpy.models.v0042_partition_info_qos import V0042PartitionInfoQos
from slurmrestpy.models.v0042_partition_info_tres import V0042PartitionInfoTres


class V0040PartitionInfo(BaseModel):
    """
    V0040PartitionInfo
    """  # noqa: E501

    nodes: Optional[V0042PartitionInfoNodes] = None
    accounts: Optional[V0042PartitionInfoAccounts] = None
    groups: Optional[V0042PartitionInfoGroups] = None
    qos: Optional[V0042PartitionInfoQos] = None
    alternate: Optional[StrictStr] = Field(default=None, description="Alternate")
    tres: Optional[V0042PartitionInfoTres] = None
    cluster: Optional[StrictStr] = Field(default=None, description="Cluster name")
    cpus: Optional[V0042PartitionInfoCpus] = None
    defaults: Optional[V0040PartitionInfoDefaults] = None
    grace_time: Optional[StrictInt] = Field(default=None, description="GraceTime")
    maximums: Optional[V0040PartitionInfoMaximums] = None
    minimums: Optional[V0042PartitionInfoMinimums] = None
    name: Optional[StrictStr] = Field(default=None, description="PartitionName")
    node_sets: Optional[StrictStr] = Field(default=None, description="NodeSets")
    priority: Optional[V0042PartitionInfoPriority] = None
    timeouts: Optional[V0040PartitionInfoTimeouts] = None
    partition: Optional[V0040PartitionInfoPartition] = None
    suspend_time: Optional[V0040Uint32NoVal] = None
    __properties: ClassVar[List[str]] = [
        "nodes",
        "accounts",
        "groups",
        "qos",
        "alternate",
        "tres",
        "cluster",
        "cpus",
        "defaults",
        "grace_time",
        "maximums",
        "minimums",
        "name",
        "node_sets",
        "priority",
        "timeouts",
        "partition",
        "suspend_time",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0040PartitionInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of nodes
        if self.nodes:
            _dict["nodes"] = self.nodes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of accounts
        if self.accounts:
            _dict["accounts"] = self.accounts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of groups
        if self.groups:
            _dict["groups"] = self.groups.to_dict()
        # override the default output from pydantic by calling `to_dict()` of qos
        if self.qos:
            _dict["qos"] = self.qos.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tres
        if self.tres:
            _dict["tres"] = self.tres.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cpus
        if self.cpus:
            _dict["cpus"] = self.cpus.to_dict()
        # override the default output from pydantic by calling `to_dict()` of defaults
        if self.defaults:
            _dict["defaults"] = self.defaults.to_dict()
        # override the default output from pydantic by calling `to_dict()` of maximums
        if self.maximums:
            _dict["maximums"] = self.maximums.to_dict()
        # override the default output from pydantic by calling `to_dict()` of minimums
        if self.minimums:
            _dict["minimums"] = self.minimums.to_dict()
        # override the default output from pydantic by calling `to_dict()` of priority
        if self.priority:
            _dict["priority"] = self.priority.to_dict()
        # override the default output from pydantic by calling `to_dict()` of timeouts
        if self.timeouts:
            _dict["timeouts"] = self.timeouts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of partition
        if self.partition:
            _dict["partition"] = self.partition.to_dict()
        # override the default output from pydantic by calling `to_dict()` of suspend_time
        if self.suspend_time:
            _dict["suspend_time"] = self.suspend_time.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0040PartitionInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "nodes": V0042PartitionInfoNodes.from_dict(obj["nodes"])
                if obj.get("nodes") is not None
                else None,
                "accounts": V0042PartitionInfoAccounts.from_dict(obj["accounts"])
                if obj.get("accounts") is not None
                else None,
                "groups": V0042PartitionInfoGroups.from_dict(obj["groups"])
                if obj.get("groups") is not None
                else None,
                "qos": V0042PartitionInfoQos.from_dict(obj["qos"])
                if obj.get("qos") is not None
                else None,
                "alternate": obj.get("alternate"),
                "tres": V0042PartitionInfoTres.from_dict(obj["tres"])
                if obj.get("tres") is not None
                else None,
                "cluster": obj.get("cluster"),
                "cpus": V0042PartitionInfoCpus.from_dict(obj["cpus"])
                if obj.get("cpus") is not None
                else None,
                "defaults": V0040PartitionInfoDefaults.from_dict(obj["defaults"])
                if obj.get("defaults") is not None
                else None,
                "grace_time": obj.get("grace_time"),
                "maximums": V0040PartitionInfoMaximums.from_dict(obj["maximums"])
                if obj.get("maximums") is not None
                else None,
                "minimums": V0042PartitionInfoMinimums.from_dict(obj["minimums"])
                if obj.get("minimums") is not None
                else None,
                "name": obj.get("name"),
                "node_sets": obj.get("node_sets"),
                "priority": V0042PartitionInfoPriority.from_dict(obj["priority"])
                if obj.get("priority") is not None
                else None,
                "timeouts": V0040PartitionInfoTimeouts.from_dict(obj["timeouts"])
                if obj.get("timeouts") is not None
                else None,
                "partition": V0040PartitionInfoPartition.from_dict(obj["partition"])
                if obj.get("partition") is not None
                else None,
                "suspend_time": V0040Uint32NoVal.from_dict(obj["suspend_time"])
                if obj.get("suspend_time") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimits,
)


class TestV0041OpenapiSlurmdbdConfigRespQosInnerLimits(unittest.TestCase):
    """V0041OpenapiSlurmdbdConfigRespQosInnerLimits unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdConfigRespQosInnerLimits:
        """Test V0041OpenapiSlurmdbdConfigRespQosInnerLimits
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdConfigRespQosInnerLimits`
        """
        model = V0041OpenapiSlurmdbdConfigRespQosInnerLimits()
        if include_optional:
            return V0041OpenapiSlurmdbdConfigRespQosInnerLimits(
                grace_time = 56,
                max = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max(
                    active_jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs(
                        accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        count = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count(
                            set = True,
                            infinite = True,
                            number = 56, ), ),
                    tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres(
                        total = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                type = '',
                                name = '',
                                id = 56, )
                            ],
                        minutes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes(
                            per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per(
                                qos = [
                                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                        type = '',
                                        name = '',
                                        id = 56, )
                                    ],
                                job = [

                                    ],
                                account = [

                                    ],
                                user = [

                                    ], ), ),
                        per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per(
                            node = [

                                ], ), ),
                    wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock(),
                    jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs(),
                    accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing(), ),
                factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor(
                    set = True,
                    infinite = True,
                    number = 1.337, ),
                min = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min(
                    priority_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_tres.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_tres(
                        per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_tres_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_tres_per(
                            job = [
                                slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                    type = '',
                                    name = '',
                                    id = 56,
                                    count = 56, )
                                ], ), ), )
            )
        else:
            return V0041OpenapiSlurmdbdConfigRespQosInnerLimits(
        )
        """

    def testV0041OpenapiSlurmdbdConfigRespQosInnerLimits(self):
        """Test V0041OpenapiSlurmdbdConfigRespQosInnerLimits"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_openapi_wckey_resp import V0040OpenapiWckeyResp


class TestV0040OpenapiWckeyResp(unittest.TestCase):
    """V0040OpenapiWckeyResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040OpenapiWckeyResp:
        """Test V0040OpenapiWckeyResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040OpenapiWckeyResp`
        """
        model = V0040OpenapiWckeyResp()
        if include_optional:
            return V0040OpenapiWckeyResp(
                wckeys = [
                    slurmrestpy.models.v0/0/40_wckey.v0.0.40_wckey(
                        accounting = [
                            slurmrestpy.models.v0/0/40_accounting.v0.0.40_accounting(
                                allocated = slurmrestpy.models.v0_0_40_accounting_allocated.v0_0_40_accounting_allocated(
                                    seconds = 56, ),
                                id = 56,
                                start = 56,
                                tres = slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                                    type = '',
                                    name = '',
                                    id = 56,
                                    count = 56, ), )
                            ],
                        cluster = '',
                        id = 56,
                        name = '',
                        user = '',
                        flags = [
                            'DELETED'
                            ], )
                    ],
                meta = slurmrestpy.models.v0/0/40_openapi_meta.v0.0.40_openapi_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0/0/40_openapi_error.v0.0.40_openapi_error(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0/0/40_openapi_warning.v0.0.40_openapi_warning(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0040OpenapiWckeyResp(
                wckeys = [
                    slurmrestpy.models.v0/0/40_wckey.v0.0.40_wckey(
                        accounting = [
                            slurmrestpy.models.v0/0/40_accounting.v0.0.40_accounting(
                                allocated = slurmrestpy.models.v0_0_40_accounting_allocated.v0_0_40_accounting_allocated(
                                    seconds = 56, ),
                                id = 56,
                                start = 56,
                                tres = slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                                    type = '',
                                    name = '',
                                    id = 56,
                                    count = 56, ), )
                            ],
                        cluster = '',
                        id = 56,
                        name = '',
                        user = '',
                        flags = [
                            'DELETED'
                            ], )
                    ],
        )
        """

    def testV0040OpenapiWckeyResp(self):
        """Test V0040OpenapiWckeyResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.api.slurm_api import SlurmApi


class TestSlurmApi(unittest.TestCase):
    """SlurmApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SlurmApi()

    def tearDown(self) -> None:
        pass

    def test_slurm_v0040_delete_job(self) -> None:
        """Test case for slurm_v0040_delete_job

        cancel or signal job
        """
        pass

    def test_slurm_v0040_delete_jobs(self) -> None:
        """Test case for slurm_v0040_delete_jobs

        send signal to list of jobs
        """
        pass

    def test_slurm_v0040_delete_node(self) -> None:
        """Test case for slurm_v0040_delete_node

        delete node
        """
        pass

    def test_slurm_v0040_get_diag(self) -> None:
        """Test case for slurm_v0040_get_diag

        get diagnostics
        """
        pass

    def test_slurm_v0040_get_job(self) -> None:
        """Test case for slurm_v0040_get_job

        get job info
        """
        pass

    def test_slurm_v0040_get_jobs(self) -> None:
        """Test case for slurm_v0040_get_jobs

        get list of jobs
        """
        pass

    def test_slurm_v0040_get_jobs_state(self) -> None:
        """Test case for slurm_v0040_get_jobs_state

        get list of job states
        """
        pass

    def test_slurm_v0040_get_licenses(self) -> None:
        """Test case for slurm_v0040_get_licenses

        get all Slurm tracked license info
        """
        pass

    def test_slurm_v0040_get_node(self) -> None:
        """Test case for slurm_v0040_get_node

        get node info
        """
        pass

    def test_slurm_v0040_get_nodes(self) -> None:
        """Test case for slurm_v0040_get_nodes

        get node(s) info
        """
        pass

    def test_slurm_v0040_get_partition(self) -> None:
        """Test case for slurm_v0040_get_partition

        get partition info
        """
        pass

    def test_slurm_v0040_get_partitions(self) -> None:
        """Test case for slurm_v0040_get_partitions

        get all partition info
        """
        pass

    def test_slurm_v0040_get_ping(self) -> None:
        """Test case for slurm_v0040_get_ping

        ping test
        """
        pass

    def test_slurm_v0040_get_reconfigure(self) -> None:
        """Test case for slurm_v0040_get_reconfigure

        request slurmctld reconfigure
        """
        pass

    def test_slurm_v0040_get_reservation(self) -> None:
        """Test case for slurm_v0040_get_reservation

        get reservation info
        """
        pass

    def test_slurm_v0040_get_reservations(self) -> None:
        """Test case for slurm_v0040_get_reservations

        get all reservation info
        """
        pass

    def test_slurm_v0040_get_shares(self) -> None:
        """Test case for slurm_v0040_get_shares

        get fairshare info
        """
        pass

    def test_slurm_v0040_post_job(self) -> None:
        """Test case for slurm_v0040_post_job

        update job
        """
        pass

    def test_slurm_v0040_post_job_submit(self) -> None:
        """Test case for slurm_v0040_post_job_submit

        submit new job
        """
        pass

    def test_slurm_v0040_post_node(self) -> None:
        """Test case for slurm_v0040_post_node

        update node properties
        """
        pass

    def test_slurm_v0040_post_nodes(self) -> None:
        """Test case for slurm_v0040_post_nodes

        batch update node(s)
        """
        pass

    def test_slurm_v0041_delete_job(self) -> None:
        """Test case for slurm_v0041_delete_job

        cancel or signal job
        """
        pass

    def test_slurm_v0041_delete_jobs(self) -> None:
        """Test case for slurm_v0041_delete_jobs

        send signal to list of jobs
        """
        pass

    def test_slurm_v0041_delete_node(self) -> None:
        """Test case for slurm_v0041_delete_node

        delete node
        """
        pass

    def test_slurm_v0041_get_diag(self) -> None:
        """Test case for slurm_v0041_get_diag

        get diagnostics
        """
        pass

    def test_slurm_v0041_get_job(self) -> None:
        """Test case for slurm_v0041_get_job

        get job info
        """
        pass

    def test_slurm_v0041_get_jobs(self) -> None:
        """Test case for slurm_v0041_get_jobs

        get list of jobs
        """
        pass

    def test_slurm_v0041_get_jobs_state(self) -> None:
        """Test case for slurm_v0041_get_jobs_state

        get list of job states
        """
        pass

    def test_slurm_v0041_get_licenses(self) -> None:
        """Test case for slurm_v0041_get_licenses

        get all Slurm tracked license info
        """
        pass

    def test_slurm_v0041_get_node(self) -> None:
        """Test case for slurm_v0041_get_node

        get node info
        """
        pass

    def test_slurm_v0041_get_nodes(self) -> None:
        """Test case for slurm_v0041_get_nodes

        get node(s) info
        """
        pass

    def test_slurm_v0041_get_partition(self) -> None:
        """Test case for slurm_v0041_get_partition

        get partition info
        """
        pass

    def test_slurm_v0041_get_partitions(self) -> None:
        """Test case for slurm_v0041_get_partitions

        get all partition info
        """
        pass

    def test_slurm_v0041_get_ping(self) -> None:
        """Test case for slurm_v0041_get_ping

        ping test
        """
        pass

    def test_slurm_v0041_get_reconfigure(self) -> None:
        """Test case for slurm_v0041_get_reconfigure

        request slurmctld reconfigure
        """
        pass

    def test_slurm_v0041_get_reservation(self) -> None:
        """Test case for slurm_v0041_get_reservation

        get reservation info
        """
        pass

    def test_slurm_v0041_get_reservations(self) -> None:
        """Test case for slurm_v0041_get_reservations

        get all reservation info
        """
        pass

    def test_slurm_v0041_get_shares(self) -> None:
        """Test case for slurm_v0041_get_shares

        get fairshare info
        """
        pass

    def test_slurm_v0041_post_job(self) -> None:
        """Test case for slurm_v0041_post_job

        update job
        """
        pass

    def test_slurm_v0041_post_job_allocate(self) -> None:
        """Test case for slurm_v0041_post_job_allocate

        submit new job allocation without any steps that must be signaled to stop
        """
        pass

    def test_slurm_v0041_post_job_submit(self) -> None:
        """Test case for slurm_v0041_post_job_submit

        submit new job
        """
        pass

    def test_slurm_v0041_post_node(self) -> None:
        """Test case for slurm_v0041_post_node

        update node properties
        """
        pass

    def test_slurm_v0041_post_nodes(self) -> None:
        """Test case for slurm_v0041_post_nodes

        batch update node(s)
        """
        pass

    def test_slurm_v0042_delete_job(self) -> None:
        """Test case for slurm_v0042_delete_job

        cancel or signal job
        """
        pass

    def test_slurm_v0042_delete_jobs(self) -> None:
        """Test case for slurm_v0042_delete_jobs

        send signal to list of jobs
        """
        pass

    def test_slurm_v0042_delete_node(self) -> None:
        """Test case for slurm_v0042_delete_node

        delete node
        """
        pass

    def test_slurm_v0042_get_diag(self) -> None:
        """Test case for slurm_v0042_get_diag

        get diagnostics
        """
        pass

    def test_slurm_v0042_get_job(self) -> None:
        """Test case for slurm_v0042_get_job

        get job info
        """
        pass

    def test_slurm_v0042_get_jobs(self) -> None:
        """Test case for slurm_v0042_get_jobs

        get list of jobs
        """
        pass

    def test_slurm_v0042_get_jobs_state(self) -> None:
        """Test case for slurm_v0042_get_jobs_state

        get list of job states
        """
        pass

    def test_slurm_v0042_get_licenses(self) -> None:
        """Test case for slurm_v0042_get_licenses

        get all Slurm tracked license info
        """
        pass

    def test_slurm_v0042_get_node(self) -> None:
        """Test case for slurm_v0042_get_node

        get node info
        """
        pass

    def test_slurm_v0042_get_nodes(self) -> None:
        """Test case for slurm_v0042_get_nodes

        get node(s) info
        """
        pass

    def test_slurm_v0042_get_partition(self) -> None:
        """Test case for slurm_v0042_get_partition

        get partition info
        """
        pass

    def test_slurm_v0042_get_partitions(self) -> None:
        """Test case for slurm_v0042_get_partitions

        get all partition info
        """
        pass

    def test_slurm_v0042_get_ping(self) -> None:
        """Test case for slurm_v0042_get_ping

        ping test
        """
        pass

    def test_slurm_v0042_get_reconfigure(self) -> None:
        """Test case for slurm_v0042_get_reconfigure

        request slurmctld reconfigure
        """
        pass

    def test_slurm_v0042_get_reservation(self) -> None:
        """Test case for slurm_v0042_get_reservation

        get reservation info
        """
        pass

    def test_slurm_v0042_get_reservations(self) -> None:
        """Test case for slurm_v0042_get_reservations

        get all reservation info
        """
        pass

    def test_slurm_v0042_get_shares(self) -> None:
        """Test case for slurm_v0042_get_shares

        get fairshare info
        """
        pass

    def test_slurm_v0042_post_job(self) -> None:
        """Test case for slurm_v0042_post_job

        update job
        """
        pass

    def test_slurm_v0042_post_job_allocate(self) -> None:
        """Test case for slurm_v0042_post_job_allocate

        submit new job allocation without any steps that must be signaled to stop
        """
        pass

    def test_slurm_v0042_post_job_submit(self) -> None:
        """Test case for slurm_v0042_post_job_submit

        submit new job
        """
        pass

    def test_slurm_v0042_post_node(self) -> None:
        """Test case for slurm_v0042_post_node

        update node properties
        """
        pass

    def test_slurm_v0042_post_nodes(self) -> None:
        """Test case for slurm_v0042_post_nodes

        batch update node(s)
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_meta import (
    V0041OpenapiSlurmdbdJobsRespMeta,
)


class TestV0041OpenapiSlurmdbdJobsRespMeta(unittest.TestCase):
    """V0041OpenapiSlurmdbdJobsRespMeta unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiSlurmdbdJobsRespMeta:
        """Test V0041OpenapiSlurmdbdJobsRespMeta
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdJobsRespMeta`
        """
        model = V0041OpenapiSlurmdbdJobsRespMeta()
        if include_optional:
            return V0041OpenapiSlurmdbdJobsRespMeta(
                plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                    type = '',
                    name = '',
                    data_parser = '',
                    accounting_storage = '', ),
                client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                    source = '',
                    user = '',
                    group = '', ),
                command = [
                    ''
                    ],
                slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                    version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                        major = '',
                        micro = '',
                        minor = '', ),
                    release = '',
                    cluster = '', )
            )
        else:
            return V0041OpenapiSlurmdbdJobsRespMeta(
        )
        """

    def testV0041OpenapiSlurmdbdJobsRespMeta(self):
        """Test V0041OpenapiSlurmdbdJobsRespMeta"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing_extensions import Self


class V0040License(BaseModel):
    """
    V0040License
    """  # noqa: E501

    license_name: Optional[StrictStr] = Field(
        default=None, description="Name of the license", alias="LicenseName"
    )
    total: Optional[StrictInt] = Field(
        default=None, description="Total number of licenses present", alias="Total"
    )
    used: Optional[StrictInt] = Field(
        default=None, description="Number of licenses in use", alias="Used"
    )
    free: Optional[StrictInt] = Field(
        default=None, description="Number of licenses currently available", alias="Free"
    )
    remote: Optional[StrictBool] = Field(
        default=None,
        description="Indicates whether licenses are served by the database",
        alias="Remote",
    )
    reserved: Optional[StrictInt] = Field(
        default=None, description="Number of licenses reserved", alias="Reserved"
    )
    last_consumed: Optional[StrictInt] = Field(
        default=None,
        description="Last known number of licenses that were consumed in the license manager (Remote Only)",
        alias="LastConsumed",
    )
    last_deficit: Optional[StrictInt] = Field(
        default=None,
        description='Number of "missing licenses" from the cluster\'s perspective',
        alias="LastDeficit",
    )
    last_update: Optional[StrictInt] = Field(
        default=None,
        description="When the license information was last updated (UNIX Timestamp)",
        alias="LastUpdate",
    )
    __properties: ClassVar[List[str]] = [
        "LicenseName",
        "Total",
        "Used",
        "Free",
        "Remote",
        "Reserved",
        "LastConsumed",
        "LastDeficit",
        "LastUpdate",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0040License from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0040License from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "LicenseName": obj.get("LicenseName"),
                "Total": obj.get("Total"),
                "Used": obj.get("Used"),
                "Free": obj.get("Free"),
                "Remote": obj.get("Remote"),
                "Reserved": obj.get("Reserved"),
                "LastConsumed": obj.get("LastConsumed"),
                "LastDeficit": obj.get("LastDeficit"),
                "LastUpdate": obj.get("LastUpdate"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_job_desc_msg_rlimits import V0041JobDescMsgRlimits


class TestV0041JobDescMsgRlimits(unittest.TestCase):
    """V0041JobDescMsgRlimits unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041JobDescMsgRlimits:
        """Test V0041JobDescMsgRlimits
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041JobDescMsgRlimits`
        """
        model = V0041JobDescMsgRlimits()
        if include_optional:
            return V0041JobDescMsgRlimits(
                cpu = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_cpu.v0_0_41_job_desc_msg_rlimits_cpu(
                    set = True,
                    infinite = True,
                    number = 56, ),
                fsize = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_fsize.v0_0_41_job_desc_msg_rlimits_fsize(
                    set = True,
                    infinite = True,
                    number = 56, ),
                data = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_data.v0_0_41_job_desc_msg_rlimits_data(
                    set = True,
                    infinite = True,
                    number = 56, ),
                stack = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_stack.v0_0_41_job_desc_msg_rlimits_stack(
                    set = True,
                    infinite = True,
                    number = 56, ),
                core = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_core.v0_0_41_job_desc_msg_rlimits_core(
                    set = True,
                    infinite = True,
                    number = 56, ),
                rss = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_rss.v0_0_41_job_desc_msg_rlimits_rss(
                    set = True,
                    infinite = True,
                    number = 56, ),
                nproc = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nproc.v0_0_41_job_desc_msg_rlimits_nproc(
                    set = True,
                    infinite = True,
                    number = 56, ),
                nofile = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nofile.v0_0_41_job_desc_msg_rlimits_nofile(
                    set = True,
                    infinite = True,
                    number = 56, ),
                memlock = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_memlock.v0_0_41_job_desc_msg_rlimits_memlock(
                    set = True,
                    infinite = True,
                    number = 56, ),
                var_as = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_as.v0_0_41_job_desc_msg_rlimits_as(
                    set = True,
                    infinite = True,
                    number = 56, )
            )
        else:
            return V0041JobDescMsgRlimits(
        )
        """

    def testV0041JobDescMsgRlimits(self):
        """Test V0041JobDescMsgRlimits"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Self

from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner import (
    V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInnerSocketsInner,
)
from slurmrestpy.models.v0042_job_res_node_cpus import V0042JobResNodeCpus
from slurmrestpy.models.v0042_job_res_node_memory import V0042JobResNodeMemory


class V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner(BaseModel):
    """
    Job resources for a node
    """  # noqa: E501

    index: StrictInt = Field(description="Node index")
    name: StrictStr = Field(description="Node name")
    cpus: Optional[V0042JobResNodeCpus] = None
    memory: Optional[V0042JobResNodeMemory] = None
    sockets: List[
        V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInnerSocketsInner
    ] = Field(description="Socket allocations in node")
    __properties: ClassVar[List[str]] = ["index", "name", "cpus", "memory", "sockets"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of cpus
        if self.cpus:
            _dict["cpus"] = self.cpus.to_dict()
        # override the default output from pydantic by calling `to_dict()` of memory
        if self.memory:
            _dict["memory"] = self.memory.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in sockets (list)
        _items = []
        if self.sockets:
            for _item_sockets in self.sockets:
                if _item_sockets:
                    _items.append(_item_sockets.to_dict())
            _dict["sockets"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "index": obj.get("index"),
                "name": obj.get("name"),
                "cpus": V0042JobResNodeCpus.from_dict(obj["cpus"])
                if obj.get("cpus") is not None
                else None,
                "memory": V0042JobResNodeMemory.from_dict(obj["memory"])
                if obj.get("memory") is not None
                else None,
                "sockets": [
                    V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInnerSocketsInner.from_dict(
                        _item
                    )
                    for _item in obj["sockets"]
                ]
                if obj.get("sockets") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner import (
    V0041OpenapiReservationRespReservationsInner,
)


class TestV0041OpenapiReservationRespReservationsInner(unittest.TestCase):
    """V0041OpenapiReservationRespReservationsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiReservationRespReservationsInner:
        """Test V0041OpenapiReservationRespReservationsInner
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiReservationRespReservationsInner`
        """
        model = V0041OpenapiReservationRespReservationsInner()
        if include_optional:
            return V0041OpenapiReservationRespReservationsInner(
                accounts = '',
                burst_buffer = '',
                core_count = 56,
                core_specializations = [
                    slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_core_specializations_inner.v0_0_41_openapi_reservation_resp_reservations_inner_core_specializations_inner(
                        node = '',
                        core = '', )
                    ],
                end_time = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_end_time.v0_0_41_openapi_reservation_resp_reservations_inner_end_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                features = '',
                flags = [
                    'MAINT'
                    ],
                groups = '',
                licenses = '',
                max_start_delay = 56,
                name = '',
                node_count = 56,
                node_list = '',
                partition = '',
                purge_completed = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed(
                    time = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed_time.v0_0_41_openapi_reservation_resp_reservations_inner_purge_completed_time(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                start_time = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_start_time.v0_0_41_openapi_reservation_resp_reservations_inner_start_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                watts = slurmrestpy.models.v0_0_41_openapi_reservation_resp_reservations_inner_watts.v0_0_41_openapi_reservation_resp_reservations_inner_watts(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tres = '',
                users = ''
            )
        else:
            return V0041OpenapiReservationRespReservationsInner(
        )
        """

    def testV0041OpenapiReservationRespReservationsInner(self):
        """Test V0041OpenapiReservationRespReservationsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_job_array import V0042JobArray


class TestV0042JobArray(unittest.TestCase):
    """V0042JobArray unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042JobArray:
        """Test V0042JobArray
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042JobArray`
        """
        model = V0042JobArray()
        if include_optional:
            return V0042JobArray(
                job_id = 56,
                limits = slurmrestpy.models.v0_0_42_job_array_limits.v0_0_42_job_array_limits(
                    max = slurmrestpy.models.v0_0_42_job_array_limits_max.v0_0_42_job_array_limits_max(
                        running = slurmrestpy.models.v0_0_42_job_array_limits_max_running.v0_0_42_job_array_limits_max_running(
                            tasks = 56, ), ), ),
                task_id = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                task = ''
            )
        else:
            return V0042JobArray(
        )
        """

    def testV0042JobArray(self):
        """Test V0042JobArray"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_jobs import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs,
)


class TestV0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs(unittest.TestCase):
    """V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs:
        """Test V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs`
        """
        model = V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs()
        if include_optional:
            return V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs(
                per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per(
                    count = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    submitted = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per_submitted.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per_submitted(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_job.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_job(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                active = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_active.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_active(
                    set = True,
                    infinite = True,
                    number = 56, ),
                accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_accruing(
                    set = True,
                    infinite = True,
                    number = 56, ),
                total = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_total.v0_0_41_openapi_slurmdbd_config_resp_associations_inner_max_jobs_total(
                    set = True,
                    infinite = True,
                    number = 56, )
            )
        else:
            return V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs(
        )
        """

    def testV0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs(self):
        """Test V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_step_tres_requested import V0042StepTresRequested


class TestV0042StepTresRequested(unittest.TestCase):
    """V0042StepTresRequested unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042StepTresRequested:
        """Test V0042StepTresRequested
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042StepTresRequested`
        """
        model = V0042StepTresRequested()
        if include_optional:
            return V0042StepTresRequested(
                max = [
                    slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                min = [
                    slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                average = [
                    slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                total = [
                    slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ]
            )
        else:
            return V0042StepTresRequested(
        )
        """

    def testV0042StepTresRequested(self):
        """Test V0042StepTresRequested"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_node import V0042Node


class TestV0042Node(unittest.TestCase):
    """V0042Node unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042Node:
        """Test V0042Node
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042Node`
        """
        model = V0042Node()
        if include_optional:
            return V0042Node(
                architecture = '',
                burstbuffer_network_address = '',
                boards = 56,
                boot_time = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cluster_name = '',
                cores = 56,
                specialized_cores = 56,
                cpu_binding = 56,
                cpu_load = 56,
                free_mem = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpus = 56,
                effective_cpus = 56,
                specialized_cpus = '',
                energy = slurmrestpy.models.v0/0/42_acct_gather_energy.v0.0.42_acct_gather_energy(
                    average_watts = 56,
                    base_consumed_energy = 56,
                    consumed_energy = 56,
                    current_watts = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    previous_consumed_energy = 56,
                    last_collected = 56, ),
                external_sensors = slurmrestpy.models.external_sensors.external_sensors(),
                extra = '',
                power = slurmrestpy.models.power.power(),
                features = [
                    ''
                    ],
                active_features = [
                    ''
                    ],
                gpu_spec = '',
                gres = '',
                gres_drained = '',
                gres_used = '',
                instance_id = '',
                instance_type = '',
                last_busy = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                mcs_label = '',
                specialized_memory = 56,
                name = '',
                next_state_after_reboot = [
                    'INVALID'
                    ],
                address = '',
                hostname = '',
                state = [
                    'INVALID'
                    ],
                operating_system = '',
                owner = '',
                partitions = [
                    ''
                    ],
                port = 56,
                real_memory = 56,
                res_cores_per_gpu = 56,
                comment = '',
                reason = '',
                reason_changed_at = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                reason_set_by_user = '',
                resume_after = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                reservation = '',
                alloc_memory = 56,
                alloc_cpus = 56,
                alloc_idle_cpus = 56,
                tres_used = '',
                tres_weighted = 1.337,
                slurmd_start_time = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                sockets = 56,
                threads = 56,
                temporary_disk = 56,
                weight = 56,
                tres = '',
                version = ''
            )
        else:
            return V0042Node(
        )
        """

    def testV0042Node(self):
        """Test V0042Node"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_assoc_shares_obj_wrap import V0040AssocSharesObjWrap


class TestV0040AssocSharesObjWrap(unittest.TestCase):
    """V0040AssocSharesObjWrap unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040AssocSharesObjWrap:
        """Test V0040AssocSharesObjWrap
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040AssocSharesObjWrap`
        """
        model = V0040AssocSharesObjWrap()
        if include_optional:
            return V0040AssocSharesObjWrap(
                id = 56,
                cluster = '',
                name = '',
                parent = '',
                partition = '',
                shares_normalized = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                    set = True,
                    infinite = True,
                    number = 1.337, ),
                shares = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tres = slurmrestpy.models.v0_0_40_assoc_shares_obj_wrap_tres.v0_0_40_assoc_shares_obj_wrap_tres(
                    run_seconds = [
                        slurmrestpy.models.v0/0/40_shares_uint64_tres.v0.0.40_shares_uint64_tres(
                            name = '',
                            value = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                                set = True,
                                infinite = True,
                                number = 56, ), )
                        ],
                    group_minutes = [
                        slurmrestpy.models.v0/0/40_shares_uint64_tres.v0.0.40_shares_uint64_tres(
                            name = '', )
                        ],
                    usage = [
                        slurmrestpy.models.v0/0/40_shares_float128_tres.v0.0.40_shares_float128_tres(
                            name = '', )
                        ], ),
                effective_usage = 1.337,
                usage_normalized = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                    set = True,
                    infinite = True,
                    number = 1.337, ),
                usage = 56,
                fairshare = slurmrestpy.models.v0_0_40_assoc_shares_obj_wrap_fairshare.v0_0_40_assoc_shares_obj_wrap_fairshare(
                    factor = 1.337,
                    level = 1.337, ),
                type = [
                    'USER'
                    ]
            )
        else:
            return V0040AssocSharesObjWrap(
        )
        """

    def testV0040AssocSharesObjWrap(self):
        """Test V0040AssocSharesObjWrap"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_job_res import V0042JobRes


class TestV0042JobRes(unittest.TestCase):
    """V0042JobRes unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042JobRes:
        """Test V0042JobRes
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042JobRes`
        """
        model = V0042JobRes()
        if include_optional:
            return V0042JobRes(
                select_type = [
                    'CPU'
                    ],
                nodes = slurmrestpy.models.v0_0_42_job_res_nodes.v0_0_42_job_res_nodes(
                    count = 56,
                    select_type = [
                        'AVAILABLE'
                        ],
                    list = '',
                    whole = True,
                    allocation = [
                        slurmrestpy.models.v0/0/42_job_res_node.v0.0.42_job_res_node(
                            index = 56,
                            name = '',
                            cpus = slurmrestpy.models.v0_0_42_job_res_node_cpus.v0_0_42_job_res_node_cpus(
                                count = 56,
                                used = 56, ),
                            memory = slurmrestpy.models.v0_0_42_job_res_node_memory.v0_0_42_job_res_node_memory(
                                used = 56,
                                allocated = 56, ),
                            sockets = [
                                slurmrestpy.models.v0/0/42_job_res_socket.v0.0.42_job_res_socket(
                                    index = 56,
                                    cores = [
                                        slurmrestpy.models.v0/0/42_job_res_core.v0.0.42_job_res_core(
                                            index = 56,
                                            status = [
                                                'INVALID'
                                                ], )
                                        ], )
                                ], )
                        ], ),
                cpus = 56,
                threads_per_core = slurmrestpy.models.v0/0/42_uint16_no_val_struct.v0.0.42_uint16_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, )
            )
        else:
            return V0042JobRes(
                select_type = [
                    'CPU'
                    ],
                cpus = 56,
                threads_per_core = slurmrestpy.models.v0/0/42_uint16_no_val_struct.v0.0.42_uint16_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
        )
        """

    def testV0042JobRes(self):
        """Test V0042JobRes"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
